
# surfingcrypto


![img](https://github.com/giocaizzi/surfingcrypto/blob/gh-pages/docsrc/source/images/logo.png)

![PyPI](https://img.shields.io/pypi/v/surfingcrypto?color=blue)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/surfingcrypto)
[![Testing](https://github.com/giocaizzi/surfingcrypto/actions/workflows/tests.yml/badge.svg?branch=main)](https://github.com/giocaizzi/surfingcrypto/actions/workflows/tests.yml)
[![codecov](https://codecov.io/gh/giocaizzi/surfingcrypto/branch/main/graph/badge.svg?token=06LXACLA9H)](https://codecov.io/gh/giocaizzi/surfingcrypto)
[![Requirements Status](https://requires.io/github/giocaizzi/surfingcrypto/requirements.svg?branch=main)](https://requires.io/github/giocaizzi/surfingcrypto/requirements/?branch=main)
![black](https://img.shields.io/badge/code%20style-black-black)

python package to surf crypto-waves.

- Scrapes *OHLC data* from [www.coinmarketcap.com](www.coinmarketcap.com) and stores it locally.
- Compute *Technical Analysis* indicators and plot complex graphs
- Interact with *Coinbase API* to read transaction data and to compute Portfolio statistics

## Installation

1. First, install direct requirements
   ```shell
   pip install git+https://github.com/giocaizzi/pyfolio.git
   pip install git+https://github.com/mementum/backtrader.git@0fa63ef4a35dc53cc7320813f8b15480c8f85517#egg=backtrader


2. Install with `pip`
   ```shell
   pip install surfingcrypto
   ```

## Documentation

### Read the docs

Documentations can be found [here](https://giocaizzi.github.io/surfingcrypto/)


